// Copyright (c) 2016, 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
// This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
// Code generated. DO NOT EDIT.

package vulnerabilityscanning

import (
	"github.com/oracle/oci-go-sdk/v40/common"
	"net/http"
)

// ListHostPortScanResultsRequest wrapper for the ListHostPortScanResults operation
//
// See also
//
// Click https://docs.cloud.oracle.com/en-us/iaas/tools/go-sdk-examples/latest/vulnerabilityscanning/ListHostPortScanResults.go.html to see an example of how to use ListHostPortScanResultsRequest.
type ListHostPortScanResultsRequest struct {

	// The ID of the compartment in which to list resources.
	CompartmentId *string `mandatory:"true" contributesTo:"query" name:"compartmentId"`

	// The ID of a compute instance
	InstanceId *string `mandatory:"false" contributesTo:"query" name:"instanceId"`

	// Parameter to filter by highestProblemSeverity for scan results
	HighestProblemSeverity ListHostPortScanResultsHighestProblemSeverityEnum `mandatory:"false" contributesTo:"query" name:"highestProblemSeverity" omitEmpty:"true"`

	// Date and time on or after which scans were started, as described in RFC 3339 (https://tools.ietf.org/rfc/rfc3339)
	TimeStartedGreaterThanOrEqualTo *common.SDKTime `mandatory:"false" contributesTo:"query" name:"timeStartedGreaterThanOrEqualTo"`

	// Date and time on or before which scans were started, as described in RFC 3339 (https://tools.ietf.org/rfc/rfc3339)
	TimeStartedLessThanOrEqualTo *common.SDKTime `mandatory:"false" contributesTo:"query" name:"timeStartedLessThanOrEqualTo"`

	// The sort order to use, either 'ASC' or 'DESC'.
	SortOrder ListHostPortScanResultsSortOrderEnum `mandatory:"false" contributesTo:"query" name:"sortOrder" omitEmpty:"true"`

	// The field to sort by. Only one sort order may be provided. Default order is descending. If no value is specified timeFinished is default.
	SortBy ListHostPortScanResultsSortByEnum `mandatory:"false" contributesTo:"query" name:"sortBy" omitEmpty:"true"`

	// The maximum number of items to return.
	Limit *int `mandatory:"false" contributesTo:"query" name:"limit"`

	// The page token representing the page at which to start retrieving results. This is usually retrieved from a previous list call.
	Page *string `mandatory:"false" contributesTo:"query" name:"page"`

	// The client request ID for tracing.
	OpcRequestId *string `mandatory:"false" contributesTo:"header" name:"opc-request-id"`

	// A filter to return only resources that match the entire display name given.
	DisplayName *string `mandatory:"false" contributesTo:"query" name:"displayName"`

	// Metadata about the request. This information will not be transmitted to the service, but
	// represents information that the SDK will consume to drive retry behavior.
	RequestMetadata common.RequestMetadata
}

func (request ListHostPortScanResultsRequest) String() string {
	return common.PointerString(request)
}

// HTTPRequest implements the OCIRequest interface
func (request ListHostPortScanResultsRequest) HTTPRequest(method, path string, binaryRequestBody *common.OCIReadSeekCloser) (http.Request, error) {

	return common.MakeDefaultHTTPRequestWithTaggedStruct(method, path, request)
}

// BinaryRequestBody implements the OCIRequest interface
func (request ListHostPortScanResultsRequest) BinaryRequestBody() (*common.OCIReadSeekCloser, bool) {

	return nil, false

}

// RetryPolicy implements the OCIRetryableRequest interface. This retrieves the specified retry policy.
func (request ListHostPortScanResultsRequest) RetryPolicy() *common.RetryPolicy {
	return request.RequestMetadata.RetryPolicy
}

// ListHostPortScanResultsResponse wrapper for the ListHostPortScanResults operation
type ListHostPortScanResultsResponse struct {

	// The underlying http response
	RawResponse *http.Response

	// A list of HostPortScanResultSummaryCollection instances
	HostPortScanResultSummaryCollection `presentIn:"body"`

	// Unique Oracle-assigned identifier for the request. If you need to contact
	// Oracle about a particular request, please provide the request ID.
	OpcRequestId *string `presentIn:"header" name:"opc-request-id"`

	// For pagination of a list of items. When paging through a list, if this header appears in the response,
	// then a partial list might have been returned. Include this value as the `page` parameter for the
	// subsequent GET request to get the next batch of items.
	OpcNextPage *string `presentIn:"header" name:"opc-next-page"`
}

func (response ListHostPortScanResultsResponse) String() string {
	return common.PointerString(response)
}

// HTTPResponse implements the OCIResponse interface
func (response ListHostPortScanResultsResponse) HTTPResponse() *http.Response {
	return response.RawResponse
}

// ListHostPortScanResultsHighestProblemSeverityEnum Enum with underlying type: string
type ListHostPortScanResultsHighestProblemSeverityEnum string

// Set of constants representing the allowable values for ListHostPortScanResultsHighestProblemSeverityEnum
const (
	ListHostPortScanResultsHighestProblemSeverityNone     ListHostPortScanResultsHighestProblemSeverityEnum = "NONE"
	ListHostPortScanResultsHighestProblemSeverityLow      ListHostPortScanResultsHighestProblemSeverityEnum = "LOW"
	ListHostPortScanResultsHighestProblemSeverityMedium   ListHostPortScanResultsHighestProblemSeverityEnum = "MEDIUM"
	ListHostPortScanResultsHighestProblemSeverityHigh     ListHostPortScanResultsHighestProblemSeverityEnum = "HIGH"
	ListHostPortScanResultsHighestProblemSeverityCritical ListHostPortScanResultsHighestProblemSeverityEnum = "CRITICAL"
)

var mappingListHostPortScanResultsHighestProblemSeverity = map[string]ListHostPortScanResultsHighestProblemSeverityEnum{
	"NONE":     ListHostPortScanResultsHighestProblemSeverityNone,
	"LOW":      ListHostPortScanResultsHighestProblemSeverityLow,
	"MEDIUM":   ListHostPortScanResultsHighestProblemSeverityMedium,
	"HIGH":     ListHostPortScanResultsHighestProblemSeverityHigh,
	"CRITICAL": ListHostPortScanResultsHighestProblemSeverityCritical,
}

// GetListHostPortScanResultsHighestProblemSeverityEnumValues Enumerates the set of values for ListHostPortScanResultsHighestProblemSeverityEnum
func GetListHostPortScanResultsHighestProblemSeverityEnumValues() []ListHostPortScanResultsHighestProblemSeverityEnum {
	values := make([]ListHostPortScanResultsHighestProblemSeverityEnum, 0)
	for _, v := range mappingListHostPortScanResultsHighestProblemSeverity {
		values = append(values, v)
	}
	return values
}

// ListHostPortScanResultsSortOrderEnum Enum with underlying type: string
type ListHostPortScanResultsSortOrderEnum string

// Set of constants representing the allowable values for ListHostPortScanResultsSortOrderEnum
const (
	ListHostPortScanResultsSortOrderAsc  ListHostPortScanResultsSortOrderEnum = "ASC"
	ListHostPortScanResultsSortOrderDesc ListHostPortScanResultsSortOrderEnum = "DESC"
)

var mappingListHostPortScanResultsSortOrder = map[string]ListHostPortScanResultsSortOrderEnum{
	"ASC":  ListHostPortScanResultsSortOrderAsc,
	"DESC": ListHostPortScanResultsSortOrderDesc,
}

// GetListHostPortScanResultsSortOrderEnumValues Enumerates the set of values for ListHostPortScanResultsSortOrderEnum
func GetListHostPortScanResultsSortOrderEnumValues() []ListHostPortScanResultsSortOrderEnum {
	values := make([]ListHostPortScanResultsSortOrderEnum, 0)
	for _, v := range mappingListHostPortScanResultsSortOrder {
		values = append(values, v)
	}
	return values
}

// ListHostPortScanResultsSortByEnum Enum with underlying type: string
type ListHostPortScanResultsSortByEnum string

// Set of constants representing the allowable values for ListHostPortScanResultsSortByEnum
const (
	ListHostPortScanResultsSortByTimestarted            ListHostPortScanResultsSortByEnum = "timeStarted"
	ListHostPortScanResultsSortByTimefinished           ListHostPortScanResultsSortByEnum = "timeFinished"
	ListHostPortScanResultsSortByOpenportcount          ListHostPortScanResultsSortByEnum = "openPortCount"
	ListHostPortScanResultsSortByHighestproblemseverity ListHostPortScanResultsSortByEnum = "highestProblemSeverity"
	ListHostPortScanResultsSortByTimecompleted          ListHostPortScanResultsSortByEnum = "timeCompleted"
)

var mappingListHostPortScanResultsSortBy = map[string]ListHostPortScanResultsSortByEnum{
	"timeStarted":            ListHostPortScanResultsSortByTimestarted,
	"timeFinished":           ListHostPortScanResultsSortByTimefinished,
	"openPortCount":          ListHostPortScanResultsSortByOpenportcount,
	"highestProblemSeverity": ListHostPortScanResultsSortByHighestproblemseverity,
	"timeCompleted":          ListHostPortScanResultsSortByTimecompleted,
}

// GetListHostPortScanResultsSortByEnumValues Enumerates the set of values for ListHostPortScanResultsSortByEnum
func GetListHostPortScanResultsSortByEnumValues() []ListHostPortScanResultsSortByEnum {
	values := make([]ListHostPortScanResultsSortByEnum, 0)
	for _, v := range mappingListHostPortScanResultsSortBy {
		values = append(values, v)
	}
	return values
}
