// Copyright (c) 2016, 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
// This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
// Code generated. DO NOT EDIT.

package vulnerabilityscanning

import (
	"github.com/oracle/oci-go-sdk/v40/common"
	"net/http"
)

// ListHostVulnerabilitiesRequest wrapper for the ListHostVulnerabilities operation
//
// See also
//
// Click https://docs.cloud.oracle.com/en-us/iaas/tools/go-sdk-examples/latest/vulnerabilityscanning/ListHostVulnerabilities.go.html to see an example of how to use ListHostVulnerabilitiesRequest.
type ListHostVulnerabilitiesRequest struct {

	// The ID of the compartment in which to list resources.
	CompartmentId *string `mandatory:"true" contributesTo:"query" name:"compartmentId"`

	// The maximum number of items to return.
	Limit *int `mandatory:"false" contributesTo:"query" name:"limit"`

	// The page token representing the page at which to start retrieving results. This is usually retrieved from a previous list call.
	Page *string `mandatory:"false" contributesTo:"query" name:"page"`

	// A filter to return only resources that have a severity that matches the given severity
	Severity ListHostVulnerabilitiesSeverityEnum `mandatory:"false" contributesTo:"query" name:"severity" omitEmpty:"true"`

	// A filter to return only resources that match the entire name given.
	Name *string `mandatory:"false" contributesTo:"query" name:"name"`

	// Parameter to filter by CVE reference number for vulnerabilities
	CveReference *string `mandatory:"false" contributesTo:"query" name:"cveReference"`

	// The field to filter vulnerabilities based on its type. Only one value can be provided.
	VulnerabilityType ListHostVulnerabilitiesVulnerabilityTypeEnum `mandatory:"false" contributesTo:"query" name:"vulnerabilityType" omitEmpty:"true"`

	// The sort order to use, either 'ASC' or 'DESC'.
	SortOrder ListHostVulnerabilitiesSortOrderEnum `mandatory:"false" contributesTo:"query" name:"sortOrder" omitEmpty:"true"`

	// The field to sort by. Only one sort order may be provided. Default order for 'name' is Ascending. Default order for other values is descending. If no value is specified name is default.
	SortBy ListHostVulnerabilitiesSortByEnum `mandatory:"false" contributesTo:"query" name:"sortBy" omitEmpty:"true"`

	// The client request ID for tracing.
	OpcRequestId *string `mandatory:"false" contributesTo:"header" name:"opc-request-id"`

	// Metadata about the request. This information will not be transmitted to the service, but
	// represents information that the SDK will consume to drive retry behavior.
	RequestMetadata common.RequestMetadata
}

func (request ListHostVulnerabilitiesRequest) String() string {
	return common.PointerString(request)
}

// HTTPRequest implements the OCIRequest interface
func (request ListHostVulnerabilitiesRequest) HTTPRequest(method, path string, binaryRequestBody *common.OCIReadSeekCloser) (http.Request, error) {

	return common.MakeDefaultHTTPRequestWithTaggedStruct(method, path, request)
}

// BinaryRequestBody implements the OCIRequest interface
func (request ListHostVulnerabilitiesRequest) BinaryRequestBody() (*common.OCIReadSeekCloser, bool) {

	return nil, false

}

// RetryPolicy implements the OCIRetryableRequest interface. This retrieves the specified retry policy.
func (request ListHostVulnerabilitiesRequest) RetryPolicy() *common.RetryPolicy {
	return request.RequestMetadata.RetryPolicy
}

// ListHostVulnerabilitiesResponse wrapper for the ListHostVulnerabilities operation
type ListHostVulnerabilitiesResponse struct {

	// The underlying http response
	RawResponse *http.Response

	// A list of HostVulnerabilitySummaryCollection instances
	HostVulnerabilitySummaryCollection `presentIn:"body"`

	// Unique Oracle-assigned identifier for the request. If you need to contact
	// Oracle about a particular request, please provide the request ID.
	OpcRequestId *string `presentIn:"header" name:"opc-request-id"`

	// For pagination of a list of items. When paging through a list, if this header appears in the response,
	// then a partial list might have been returned. Include this value as the `page` parameter for the
	// subsequent GET request to get the next batch of items.
	OpcNextPage *string `presentIn:"header" name:"opc-next-page"`
}

func (response ListHostVulnerabilitiesResponse) String() string {
	return common.PointerString(response)
}

// HTTPResponse implements the OCIResponse interface
func (response ListHostVulnerabilitiesResponse) HTTPResponse() *http.Response {
	return response.RawResponse
}

// ListHostVulnerabilitiesSeverityEnum Enum with underlying type: string
type ListHostVulnerabilitiesSeverityEnum string

// Set of constants representing the allowable values for ListHostVulnerabilitiesSeverityEnum
const (
	ListHostVulnerabilitiesSeverityNone     ListHostVulnerabilitiesSeverityEnum = "NONE"
	ListHostVulnerabilitiesSeverityLow      ListHostVulnerabilitiesSeverityEnum = "LOW"
	ListHostVulnerabilitiesSeverityMedium   ListHostVulnerabilitiesSeverityEnum = "MEDIUM"
	ListHostVulnerabilitiesSeverityHigh     ListHostVulnerabilitiesSeverityEnum = "HIGH"
	ListHostVulnerabilitiesSeverityCritical ListHostVulnerabilitiesSeverityEnum = "CRITICAL"
)

var mappingListHostVulnerabilitiesSeverity = map[string]ListHostVulnerabilitiesSeverityEnum{
	"NONE":     ListHostVulnerabilitiesSeverityNone,
	"LOW":      ListHostVulnerabilitiesSeverityLow,
	"MEDIUM":   ListHostVulnerabilitiesSeverityMedium,
	"HIGH":     ListHostVulnerabilitiesSeverityHigh,
	"CRITICAL": ListHostVulnerabilitiesSeverityCritical,
}

// GetListHostVulnerabilitiesSeverityEnumValues Enumerates the set of values for ListHostVulnerabilitiesSeverityEnum
func GetListHostVulnerabilitiesSeverityEnumValues() []ListHostVulnerabilitiesSeverityEnum {
	values := make([]ListHostVulnerabilitiesSeverityEnum, 0)
	for _, v := range mappingListHostVulnerabilitiesSeverity {
		values = append(values, v)
	}
	return values
}

// ListHostVulnerabilitiesVulnerabilityTypeEnum Enum with underlying type: string
type ListHostVulnerabilitiesVulnerabilityTypeEnum string

// Set of constants representing the allowable values for ListHostVulnerabilitiesVulnerabilityTypeEnum
const (
	ListHostVulnerabilitiesVulnerabilityTypeCve     ListHostVulnerabilitiesVulnerabilityTypeEnum = "CVE"
	ListHostVulnerabilitiesVulnerabilityTypeProblem ListHostVulnerabilitiesVulnerabilityTypeEnum = "PROBLEM"
)

var mappingListHostVulnerabilitiesVulnerabilityType = map[string]ListHostVulnerabilitiesVulnerabilityTypeEnum{
	"CVE":     ListHostVulnerabilitiesVulnerabilityTypeCve,
	"PROBLEM": ListHostVulnerabilitiesVulnerabilityTypeProblem,
}

// GetListHostVulnerabilitiesVulnerabilityTypeEnumValues Enumerates the set of values for ListHostVulnerabilitiesVulnerabilityTypeEnum
func GetListHostVulnerabilitiesVulnerabilityTypeEnumValues() []ListHostVulnerabilitiesVulnerabilityTypeEnum {
	values := make([]ListHostVulnerabilitiesVulnerabilityTypeEnum, 0)
	for _, v := range mappingListHostVulnerabilitiesVulnerabilityType {
		values = append(values, v)
	}
	return values
}

// ListHostVulnerabilitiesSortOrderEnum Enum with underlying type: string
type ListHostVulnerabilitiesSortOrderEnum string

// Set of constants representing the allowable values for ListHostVulnerabilitiesSortOrderEnum
const (
	ListHostVulnerabilitiesSortOrderAsc  ListHostVulnerabilitiesSortOrderEnum = "ASC"
	ListHostVulnerabilitiesSortOrderDesc ListHostVulnerabilitiesSortOrderEnum = "DESC"
)

var mappingListHostVulnerabilitiesSortOrder = map[string]ListHostVulnerabilitiesSortOrderEnum{
	"ASC":  ListHostVulnerabilitiesSortOrderAsc,
	"DESC": ListHostVulnerabilitiesSortOrderDesc,
}

// GetListHostVulnerabilitiesSortOrderEnumValues Enumerates the set of values for ListHostVulnerabilitiesSortOrderEnum
func GetListHostVulnerabilitiesSortOrderEnumValues() []ListHostVulnerabilitiesSortOrderEnum {
	values := make([]ListHostVulnerabilitiesSortOrderEnum, 0)
	for _, v := range mappingListHostVulnerabilitiesSortOrder {
		values = append(values, v)
	}
	return values
}

// ListHostVulnerabilitiesSortByEnum Enum with underlying type: string
type ListHostVulnerabilitiesSortByEnum string

// Set of constants representing the allowable values for ListHostVulnerabilitiesSortByEnum
const (
	ListHostVulnerabilitiesSortByName          ListHostVulnerabilitiesSortByEnum = "name"
	ListHostVulnerabilitiesSortBySeverity      ListHostVulnerabilitiesSortByEnum = "severity"
	ListHostVulnerabilitiesSortByImpactedhosts ListHostVulnerabilitiesSortByEnum = "impactedHosts"
	ListHostVulnerabilitiesSortByFirstdetected ListHostVulnerabilitiesSortByEnum = "firstDetected"
	ListHostVulnerabilitiesSortByLastdetected  ListHostVulnerabilitiesSortByEnum = "lastDetected"
)

var mappingListHostVulnerabilitiesSortBy = map[string]ListHostVulnerabilitiesSortByEnum{
	"name":          ListHostVulnerabilitiesSortByName,
	"severity":      ListHostVulnerabilitiesSortBySeverity,
	"impactedHosts": ListHostVulnerabilitiesSortByImpactedhosts,
	"firstDetected": ListHostVulnerabilitiesSortByFirstdetected,
	"lastDetected":  ListHostVulnerabilitiesSortByLastdetected,
}

// GetListHostVulnerabilitiesSortByEnumValues Enumerates the set of values for ListHostVulnerabilitiesSortByEnum
func GetListHostVulnerabilitiesSortByEnumValues() []ListHostVulnerabilitiesSortByEnum {
	values := make([]ListHostVulnerabilitiesSortByEnum, 0)
	for _, v := range mappingListHostVulnerabilitiesSortBy {
		values = append(values, v)
	}
	return values
}
